<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>NotificationActionsComboWidget</name>
    <message>
        <location filename="../notificationwidgets.cpp" line="123"/>
        <source>Actions:</source>
        <translation>Tindakan:</translation>
    </message>
    <message>
        <location filename="../notificationwidgets.cpp" line="142"/>
        <source>OK</source>
        <translation>OKE</translation>
    </message>
</context>
<context>
    <name>Notifyd</name>
    <message>
        <location filename="../notifyd.cpp" line="268"/>
        <source>Clear All</source>
        <translation>Hapus Semua</translation>
    </message>
    <message>
        <location filename="../notifyd.cpp" line="276"/>
        <source>Options</source>
        <translation>Plihan</translation>
    </message>
    <message numerus="yes">
        <location filename="../notifyd.cpp" line="283"/>
        <location filename="../notifyd.cpp" line="340"/>
        <location filename="../notifyd.cpp" line="360"/>
        <source>%n Unattended Notification(s)</source>
        <translation>
            <numerusform>%n Notifikasi Mandiri</numerusform>
        </translation>
    </message>
</context>
</TS>
